import React, { useEffect, RefObject } from 'react';
import * as d3 from 'd3';

const TimeSeries = () => {
  const ref: RefObject<HTMLDivElement> = React.createRef();
  useEffect(() => {
    draw();
  });

  const draw = () => {
    const margin = { top: 20, right: 20, bottom: 30, left: 50 };
    const width = 800 - margin.left - margin.right;
    const height = 400 - margin.top - margin.bottom;

    const container = ref.current;
    const svg = d3.select(container)
      .append('svg')
      .attr('width', width + margin.left + margin.right)
      .attr('height', height + margin.top + margin.bottom)
      .append('g')
      .attr('transform', `translate(${margin.left}, ${margin.top})`);

    const data  :{ date: Date, value: number }[] = [
      { date: new Date('2020-01-01'), value: 25 },
      { date: new Date('2020-02-01'), value: 37 },
      { date: new Date('2020-03-01'), value: 45 },
      // ...
    ];

    const xScale = d3.scaleTime()
      .range([0, width])
      .domain(d3.extent(data, (d) => d.date));

    const yScale = d3.scaleLinear()
      .range([height, 0])
      .domain([0, d3.max(data, (d) => d.value)]);

    const line = d3.line<{ date: Date, value: number }>()
      .x((d) => xScale(d.date))
      .y((d) => yScale(d.value));

    svg.append('path')
      .datum(data)
      .attr('fill', 'none')
      .attr('stroke', 'steelblue')
      .attr('stroke-width', 1.5)
      .attr('d', line);

    const xAxis = d3.axisBottom(xScale);
    const yAxis = d3.axisLeft(yScale);

    svg.append('g')
      .attr('transform', `translate(0, ${height})`)
      .call(xAxis);

    svg.append('g')
      .call(yAxis);

      const g = svg.append('g');
      
  };

  return (
    <div className="TimeSeries" ref={ref}>
    </div>
  );
};

export default TimeSeries;